@@ -1,16 +1,15 @@
 from dataclasses import dataclass
 from typing import List, Tuple
 
-import wandb
 from omegaconf import MISSING
 
+import wandb
+from fseval.config.adapters import WandbDataset
 from fseval.types import AbstractAdapter
 
 
 @dataclass
-class Wandb(AbstractAdapter):
-    artifact_id: str = MISSING
-
+class Wandb(AbstractAdapter, WandbDataset):
     def get_data(self) -> Tuple[List, List]:
         api = wandb.Api()
         artifact = api.artifact(self.artifact_id)
