@@ -1,8 +1,8 @@
 from typing import Dict, Optional
 
-from omegaconf import DictConfig
-
+import pandas as pd
 from fseval.types import Callback
+from omegaconf import DictConfig
 
 
 class CallbackCollection(Callback):
@@ -32,6 +32,10 @@ class CallbackCollection(Callback):
         for callback in self._iterator:
             callback.on_metrics(metrics)
 
+    def on_table(self, df: pd.DataFrame, name: str):
+        for callback in self._iterator:
+            callback.on_table(df, name)
+
     def on_summary(self, summary):
         for callback in self._iterator:
             callback.on_summary(summary)
